/***********************************************************************

  io_expanderFcns.h - Header file for io_expanderFcns.c

  author    John Madsen
  revision  1.0
  date      2022-06-23



  history   1.0 initial release

***********************************************************************/
#pragma once

#include "esp_system.h"


/***********************************************************************

		Defines

***********************************************************************/

#define I2C_PORT			1
//#define I2C_SCL_IO   		18
//#define I2C_SDA_IO   		17
//#define I2C_FREQ_HZ			100000
#define I2C_TIMEOUT_MS		1000

#define PCF8574AADDRESS		0x38//0x20
#define TCA9554ADDRESS		0x20

#define INPUT_PORT_REG		0x00
#define OUTPUT_PORT_REG		0x01
#define POL_INVERSION_REG	0x02		// input polarity inversion
#define CONFIGURATION_REG	0x03		// pin direction - 1 = input, 0 = output

#define OUTPUT_PORT_INIT	0x00		// set all outputs to 0 to start
#define OUTPUT_PORT_INV		0x08		// dev board - invert input
#define PORT_DIRECTIONS		0x0e		// P0, P4-7 outputs, P1, P2, P3 input



/*******************************************************************

		Structure/Enum Definitions

 *******************************************************************/

typedef enum
{
	PA_CTRL = 0x01,
	IO_FP_INT = 0x02,				// originally LCD_CTRL
	IO_USB_CONN = 0x04,				// originally LCD_RST
	IO_LID_CLOSED = 0x08,			// originally LCD_CS
	TP_INT = 0x10,
	PERI_PWR_OFF = 0x20,
	LED1 = 0x40,
	LED2 = 0x80
}ioexp_pin_t;



/***********************************************************************

		Function Prototypes

***********************************************************************/

void ioExpanderInit(void);

void ioExpanderSetOutput(ioexp_pin_t output);
void ioExpanderClearOutput(ioexp_pin_t output);
uint8_t ioExpanderReadInput(ioexp_pin_t input);
uint8_t ioExpanderReadInPort(void);






