/***********************************************************************

  io_expanderFcns.c - IO Expander functions

  author    John Madsen
  revision  1.0
  date      2022-06-16


  history   1.0 initial release

***********************************************************************/


#include "io_expander.h"
#include "../../main/include/systemFcns.h"

#include <stdio.h>
#include "freertos/FreeRTOS.h"

#include "esp_log.h"
#include "esp_system.h"
#include "driver/i2c.h"


static int pcf8574a_register_write_byte(uint8_t reg_addr, uint8_t data);
static int pcf8574a_register_read_byte(uint8_t reg_addr, uint8_t *data);
//static esp_err_t i2c_master_init(void);




static const char *Tag = "io_expander";
static ioexp_pin_t OutPortValue = 0x00;


/*******************************************************************

		Public Functions

 *******************************************************************/

void ioExpanderInit(void)
{
	int ret;

//	ret = i2c_master_init();
//    if (ret == ESP_FAIL)
//        ESP_LOGE(TAG, "I2C driver install fail!");
//    else
//        ESP_LOGI(TAG, "I2C driver install success!");
//
//
//	if (systemGetBootCount())
//		return;

    ret = pcf8574a_register_write_byte(CONFIGURATION_REG, PORT_DIRECTIONS);
    if (ret == ESP_FAIL)
        ESP_LOGE(Tag, "Init port directions fail!");
    else
        ESP_LOGI(Tag, "Init port directions success!");


    ret = pcf8574a_register_write_byte(POL_INVERSION_REG, OUTPUT_PORT_INV);
    if (ret == ESP_FAIL)
        ESP_LOGE(Tag, "Init output write fail!");
    else
        ESP_LOGI(Tag, "Init output write success!");


    ret = pcf8574a_register_write_byte(OUTPUT_PORT_REG, (uint8_t)OutPortValue);
    if (ret == ESP_FAIL)
        ESP_LOGE(Tag, "Init output write fail!");
    else
        ESP_LOGI(Tag, "Init output write success!");


}



void ioExpanderSetOutput(ioexp_pin_t output)
{
	int ret;


	OutPortValue |= output;
    ret = pcf8574a_register_write_byte(OUTPUT_PORT_REG, (uint8_t)OutPortValue);
    if (ret == ESP_FAIL)
        ESP_LOGE(Tag, "Output write fail!");
    else
        ESP_LOGI(Tag, "Output write success!");

    return;
}



void ioExpanderClearOutput(ioexp_pin_t output)
{
	int ret;


	OutPortValue &= ~output;
    ret = pcf8574a_register_write_byte(OUTPUT_PORT_REG, (uint8_t)OutPortValue);
    if (ret == ESP_FAIL)
        ESP_LOGE(Tag, "Output write fail!");
    else
        ESP_LOGI(Tag, "Output write success!");

    return;
}



uint8_t ioExpanderReadInput(ioexp_pin_t input)
{
	int ret;
	uint8_t data;


    ret = pcf8574a_register_read_byte(INPUT_PORT_REG, &data);
    if (ret == ESP_FAIL)
    {
        ESP_LOGE(Tag, "Input read fail!");
    	return 0xff;
    }
    else
    {
        ESP_LOGI(Tag, "Input read success!  %x", data);
//        return data;
        if (data & input)
        	return 1;
        else
        	return 0;
    }
}



uint8_t ioExpanderReadInPort(void)
{
	int ret;
	uint8_t data;


    ret = pcf8574a_register_read_byte(INPUT_PORT_REG, &data);
    if (ret == ESP_FAIL)
    {
        ESP_LOGE(Tag, "Input read fail!");
    	return 0xff;
    }
    else
    {
        ESP_LOGI(Tag, "Input read success!");
        return data;
    }
}



/*******************************************************************

		Private Functions

 *******************************************************************/

static int pcf8574a_register_write_byte(uint8_t reg_addr, uint8_t data)
{
    int ret;
    uint8_t write_buf[2] = {reg_addr, data};

    ret = i2c_master_write_to_device(I2C_PORT, PCF8574AADDRESS, write_buf, sizeof(write_buf), I2C_TIMEOUT_MS / portTICK_RATE_MS);

    return ret;
}



static int pcf8574a_register_read_byte(uint8_t reg_addr, uint8_t *data)
{
    int ret;

    ret = i2c_master_write_read_device(I2C_PORT, PCF8574AADDRESS, &reg_addr, sizeof(reg_addr), data, sizeof(*data), I2C_TIMEOUT_MS / portTICK_RATE_MS);

    return ret;
}



//static int tca9554_register_write_byte(uint8_t reg_addr, uint8_t data)
//{
//    int ret;
//    uint8_t write_buf[2] = {reg_addr, data};
//
//    ret = i2c_master_write_to_device(I2C_PORT, TCA9554ADDRESS, write_buf, sizeof(write_buf), I2C_TIMEOUT_MS / portTICK_RATE_MS);
//
//    return ret;
//}



//static int tca9554_register_write_byte(uint8_t reg_addr, uint8_t data)
//{
//    int ret, i;
//    uint8_t write_buf[2] = {reg_addr, data};
//
//    for (i = 0; i < 128; i++)
//    {
//    	ret = i2c_master_write_to_device(I2C_PORT, i, write_buf, sizeof(write_buf), I2C_TIMEOUT_MS / portTICK_RATE_MS);
//
//    	if (ret != ESP_FAIL)
//    		ESP_LOGI(TAG, "Output write success! Address = 0X%x/n", i);
//    }
//    return ret;
//}
//
//
//
//static esp_err_t i2c_master_init(void)
//{
//    int i2c_master_port = I2C_PORT;
//
//    i2c_config_t conf = {
//        .mode = I2C_MODE_MASTER,
//        .sda_io_num = I2C_SDA_IO,
//        .scl_io_num = I2C_SCL_IO,
//        .sda_pullup_en = GPIO_PULLUP_ENABLE,
//        .scl_pullup_en = GPIO_PULLUP_ENABLE,
//        .master.clk_speed = I2C_FREQ_HZ,
//    };
//
//    i2c_param_config(i2c_master_port, &conf);
//
//    return i2c_driver_install(i2c_master_port, conf.mode, 0, 0, 0);
//}





