/***********************************************************************

  storageFcns.h - Header file for storageFcns.c

  author    John Madsen
  revision  1.0
  date      2022-05-23



  history   1.0 initial release

***********************************************************************/
#pragma once



#include "esp_vfs.h"




/***********************************************************************

		Defines

***********************************************************************/

#define SDMMC_CLK 		15
#define SDMMC_CMD 		7
#define SDMMC_D0 		4
#define SDMMC_D1 		-1
#define SDMMC_D2 		-1
#define SDMMC_D3 		-1

#define SDMMC_WIDTH_1	1		 // can be 1, 4 or 8
#define SDMMC_WIDTH_4	4		 // can be 1, 4 or 8
#define SDMMC_WIDTH_8	8		 // can be 1, 4 or 8


#define MOUNT_POINT		"/sdcard"
#define MOUNT_POINT2	"/sdcard/"
#define HEADING			"Index,Timestamp,Event,EventSource\n"
/* Max length a file path can have on storage */
#define FILE_PATH_MAX 	(ESP_VFS_PATH_MAX + CONFIG_FATFS_MAX_LFN)




/*******************************************************************

		Structure/Enum Definitions

 *******************************************************************/

typedef unsigned int sizee_t;


// events for Event Log
typedef enum
{
	EL_DEFAULT,						// 0
	EL_FINGERPRINT_SCAN,
	EL_CREATE_EVENTLOG_FILE,
	EL_LID_RELEASE,
	EL_LID_CLOSED,
	EL_COLLAR_UNLOCK,				// 5
	EL_COLLAR_LOCK,
	EL_CHARGER_CONNECT,
	EL_DATA_TRANFER_INIT,
	EL_DATA_TRANSFER_COMPL,
	EL_BATTERY_LEVEL,				// 10, EventSource = Battery Voltage
	EL_FINGERPRINT_REGISTRATION,	// 11, EventSource = Fingerprint ID
	EL_FAILED_ACCESS_ATTEMPT,
	EL_FINGERPRINT_MATCH_SUCCESS,	// 13, EventSource = Fingerprint ID
	EL_FINGERPRINT_MATCH_FAIL,
	EL_RESET_REASON,				// 15, EventSource = Reset Cause
	EL_WAKE_CAUSE,					// 16, EventSource = Wake Cause
	EL_SLEEP_WKUP_SRCS,				// 17, EventSource = Wakeup source flags
	EL_BLE_PAIR,
	EL_BLE_UNPAIR,
	EL_BLE_CONNECT_SUCCESS,			// 20
	EL_IMAGE_CAPTURE,				// 21, EventSource = Picture #
	EL_USB_CONSOLE_CONNECT,
}eventlog_t;



typedef enum
{
	LD_FILE,
	LD_CONSOLE
}monitorlog_dest_t;



/***********************************************************************

		Function Prototypes

***********************************************************************/

void storageTask(void *pvParameter);

// initialize SD card for storage
void storageInit(void);

// de-initalize SD card
void storageDeinit(void);

// format SD card
esp_err_t storageFormatSD(void);

// convert picture frame to jpg and store
void storagePic(QueueHandle_t frame_i);

// create event log file
void storageEventLogInit(void);

// create monitor log file - monitor log goes here when not going to console
void storageSystemLogInit(void);

// write event to log file
void storageLogWriteEvent(eventlog_t event, float event_data);

// re-route stdout
void storageSetSysLogDest(monitorlog_dest_t dest);

// read jpg quality parameter
uint8_t storageGetQualJPG(void);

// set jpg quality parameter
void storageSetQualJPG(uint8_t qual);

// read directory
void storageReadDir(void);

// send file using Ymodem
int storageSendFile(char *filename);

// zip all files on SD card that are not zip files
int storageZipAllFiles(void);

// Add file to ZIP
int storageAddFileToZip(char *filename);

// print to SD card and stdout
int storprintf(const char *fmt, ...);
//
////
//static int syslog_vprintf(const char *fmt, va_list args) ;
//
//
//
//// not used; storage test example
//static void storageTest(void);



