/***********************************************************************

  systemFcns.h - Header file for systemFcns.c

  author    John Madsen
  revision  1.0
  date      2022-05-19



  history   1.0 initial release

***********************************************************************/
#pragma once

#include "esp_sleep.h"
#include "esp_system.h"




/***********************************************************************

		Defines

***********************************************************************/

#define ACTIVE_TIME		60		// seconds
#define PICTURE_DELAY	20//(5*60)	// seconds
#define IOEXP_INT		2

#define TIMESTAMP_LEN	18
//#define LED_GPIO 47



/*******************************************************************

		Structure/Enum Definitions

 *******************************************************************/

// wake up cause
typedef enum
{
	WC_USB_CONN,			// USB cable connected
	WC_FP_SENSOR,			// FP Sensor interrupt rising edge (touched)
	WC_LID_CLOSE,			// Lid closed
	WC_TIMER,				// Timer
	WC_UNDEFINED,			// Could be:  firmware download, sw reset, hw reset, panic
	WC_OTHER,				// unknown; shouldn't happen
	WC_PORT_UNKNOWN			// IO Port interrupt, could be: lid open (switch), USB Removal, fall edge FP sensor int.
}wake_cause_t;


// wake up sources flags
typedef enum
{
	WS_NULL = 0x00,
	WS_IOEXP_INT = 0x01,	// IO Expander interrupt - USB, FP Sensor, Lid Switch
	WS_TIMER = 0x02,		// Timer
}wake_source_t;


// result of operation
typedef enum
{
	FAILURE,
	SUCCESS
}result_t;


// ********** flags **********
typedef struct
{
	uint16_t collarLocked:1;
	uint16_t collarLockArm:1;
	uint16_t lidReleased:1;
	uint16_t userRegistered:1;
	uint16_t takePicture:1;
}stateflags_t;



/***********************************************************************

		Function Prototypes

***********************************************************************/

// Get and print chip, reset, and sleep data
void systemInit(void);

// Read IO Port data (get after reset, before corruption)
void systemGetIOPort(void);

// not sure if this will be used...
void systemTask(void *pvParameter);

// look at wake reason & start necessary services
void systemWake(void);

// prepare system and go into deep sleep
void systemSleep(wake_source_t wakesource);

// create timestamp
void systemTimestamp(char *timestamp);



// get cause of last wake up
wake_cause_t systemGetWakeCause(void);

// get cause of last reset
esp_reset_reason_t systemGetResetReason(void);

// get number of boots/wakes since last system reset
int systemGetBootCount(void);

// get MAC address
uint8_t* systemGetMACAddress(void);

// get flags
void systemGetFlags(void);

// clear all flags
void systemClearFlags(void);






