/***********************************************************************

  consoleCmds.c - console command functions

  author    John Madsen
  revision  1.0
  date      2022-10-18


  history   1.0 initial release

***********************************************************************/


#include "consoleCmds.h"
#include "storageFcns.h"
#include "systemFcns.h"
#include "io_expander.h"

#include <stdio.h>
#include <string.h>
#include <stddef.h>
#include <sys/time.h>
#include <time.h>
#include "esp_system.h"
#include "esp_console.h"
#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "esp_log.h"
#include "esp_spi_flash.h"
#include "argtable3/argtable3.h"
#include "fingerprint_sensor.h"



static void register_sd_dir(void);
static void register_send_file(void);



static const char* Tag = "console_cmds";
extern SemaphoreHandle_t systask_mutex;



/*******************************************************************

		Public Functions

 *******************************************************************/


void register_storage_cmds(void)
{
	register_sd_dir();
	register_send_file();
//	register_zip_file();
}




/*******************************************************************

		Private Functions

 *******************************************************************/




/* 'dir' command */
static int sd_dir(int argc, char **argv)
{
	storageReadDir();
	return 0;
}

static void register_sd_dir(void)
{
    const esp_console_cmd_t cmd = {
        .command = "dir",
        .help = "read directory on SD card",
        .hint = NULL,
        .func = &sd_dir,
    };
    ESP_ERROR_CHECK( esp_console_cmd_register(&cmd) );
}



/* 'send' command */
static int send_file(int argc, char **argv)
{

	if(argc != 2)
	{
		printf("Incorrect arguments.  Enter: send filename\n");
		return 0;
	}

//	printf("Filename:  %s\n", argv[1]);

	storageSendFile(argv[1]);
	return 0;
}

static void register_send_file(void)
{
    const esp_console_cmd_t cmd = {
        .command = "send",
        .help = "Send file. "
        		"Enter: send filename",
        .hint = NULL,
        .func = &send_file,
    };
    ESP_ERROR_CHECK( esp_console_cmd_register(&cmd) );
}







